SWAT-EM
=======

Specific Winding Analyse Tool for Electrical Machines


Installation
------------

To install, you can do:

```
pip install swat-em
```

or from the project root directory:
```
python setup.py install
```

Run the programm
----------------

Run the programm by starting it from the command line
```
swat-em
```
